@@ -6,9 +6,11 @@ Main module of BeamProfiler.
 # =============================================================================
 # Imports
 # =============================================================================
-from src.beamprofiler import analysis
 import sys
 
+from beamprofiler import analysis
+
+
 if __name__ == '__main__':
 
     # Get arguments from the command line
